module.exports = defineTest({
	description: 'handles binary expression side-effects'
});
